@@ -8,6 +8,7 @@ from utils import logging
 
 import os
 import sys
+import gobject
 
 
 class Container(Component):
@@ -23,22 +24,27 @@ class Container(Component):
     
         self.__components = []
         self.__devices = []
-        self.__whitelist = [] # whitelist
+        self.__whitelist = []
         
         Component.__init__(self)
         
         mods = self.__load_modules(plugins)
+        delayed_mods = [ mod for mod in mods if hasattr(mod, "delayed") ]
+        other_mods = [ mod for mod in mods if not hasattr(mod, "delayed") ]
+
         for mod in mods:
             self.__register_messages(mod)
-        for mod in mods:
+
+        for mod in other_mods:
             self.__load_components(mod)
-        
-        #for path in plugins:
-        #    self.load_module(path)
-        
-        #for p in paths:
-        #    if (os.path.exists(p)):
-        #        self.load_path(p)
+
+        self.__report_loadings()
+        #self.emit_message(msgs.COM_EV_APP_STARTED)
+        if (delayed_mods):
+            gobject.idle_add(self.__load_delayed_modules, delayed_mods)
+
+
+    def __report_loadings(self):
 
         for c in self.__components:
             self.emit_message(msgs.COM_EV_COMPONENT_LOADED, c)
@@ -47,38 +53,22 @@ class Container(Component):
             self.emit_message(msgs.CORE_EV_DEVICE_ADDED, dev.get_device_id(), dev)
             self.emit_message(msgs.COM_EV_COMPONENT_LOADED, dev)
 
-    """
-    def __find_modules(self, path):
-        ""
-        Returns a list of the modules of all components under the given path.
-        ""
+        self.__components = []
+        self.__devices = []
         
-        modules = []
 
-        dirs = os.listdir(path)
-        dirs.sort()
-        # a module called "core" gets loaded first
-        if ("core" in dirs):
-            dirs.remove("core")
-            dirs = ["core"] + dirs
 
-        for f in dirs:
-            comppath = os.path.join(path, f)
-            if (not os.path.isdir(comppath) or f.startswith(".")):
-                continue
+    def __load_delayed_modules(self, mods):
 
-            elif (self.__whitelist and not f in self.__whitelist and f != "core"):
-                logging.info("not loading component: %s", f)
-                continue
-            
-            mod = self.__load_module(comppath)
-            if (mod):
-                modules.append(mod)
-        #end for
+        mod = mods.pop(0)
+        self.__load_components(mod)
 
-        return modules
-    """
-    
+        if (mods):
+            gobject.idle_add(self.__load_delayed_modules, mods)
+        else:
+            self.__report_loadings()
+            self.emit_message(msgs.COM_EV_APP_STARTED)
+        
 
     def __load_module(self, path):
         """
@@ -166,27 +156,6 @@ class Container(Component):
         sys.path = syspath
 
             
-
-    """
-    def load_path(self, path):
-        ""
-        Loads all components from the given path.
-        
-        @param path: path of components directory
-        ""
-        
-        #self.__components = []
-        #self.__devices = []
-        
-        mods = self.__find_modules(path)
-        for mod in mods:
-            self.__register_messages(mod)
-        for mod in mods:
-            self.emit_message(msgs.COM_EV_LOADING_MODULE, mod.__name__)
-            self.__load_components(mod)
-    """
-
-
     def __load_modules(self, paths):
     
         return [ self.__load_module(path) for path in paths ]
