@@ -3,10 +3,10 @@ def get_classes():
     import platforms
     classes = []
 
-    if (platforms.PLATFORM == platforms.MAEMO5):
-        #from RotationMonitor import RotationMonitor
+    if (platforms.MAEMO5):
+        from RotationMonitor import RotationMonitor
         from RotationPrefs import RotationPrefs
-        #classes.append(RotationMonitor)
+        classes.append(RotationMonitor)
         classes.append(RotationPrefs)
     #end if
     
