@@ -2,15 +2,17 @@ def get_classes():
 
     from Initialiser import Initialiser
     from IdleDetector import IdleDetector
-    from AppletService import AppletService
     from BookmarkService import BookmarkService
     from DirectoryService import DirectoryService
+    from MediaOutputService import MediaOutputService
+    from ThumbnailService import ThumbnailService
 
     return [Initialiser,
             IdleDetector,
-            AppletService,
             BookmarkService,
-            DirectoryService]
+            DirectoryService,
+            MediaOutputService,
+            ThumbnailService]
 
 
 
