@@ -1,5 +1,5 @@
 from com import Component, msgs
-
+from storage import File
 import dbus
 import dbus.service
 
@@ -21,6 +21,16 @@ class DBusInterface(Component, dbus.service.Object):
                                      "/de/pycage/mediabox/control")
 
 
+    @dbus.service.method("de.pycage.mediabox.control", in_signature = "ss")
+    def load(self, uri, mimetype):
+    
+        f = self.call_service(msgs.CORE_SVC_GET_FILE,
+                              "adhoc://" + File.pack_path("/", uri, mimetype))
+        print f
+        if (f):
+            self.emit_message(msgs.MEDIA_ACT_LOAD, f)
+
+
     @dbus.service.method("de.pycage.mediabox.control")
     def play(self):
     
@@ -122,6 +132,8 @@ class DBusInterface(Component, dbus.service.Object):
     
         if (self.__need_report_position):
             self.__need_report_position = False
+            if (total == -1):
+                total = 0
             self.seek_signal(int(pos * 1000), int(total * 1000))
 
 
