@@ -1,16 +1,26 @@
+from ui.Window import Window
+from ui import windowflags
 from ui.layout import HBox
 from ui.layout import VBox
 from ui.Button import Button
 from ui.Label import Label
 from theme import theme
+import platforms
+
+import gtk
+
 
 
 # TODO: are these unicode chars supported on pre-Diablo maemo OS?
-_UP_ARROW = u"\u21e7"
-_DOWN_ARROW = u"\u21e9"
+#_UP_ARROW = u"\u21e7"
+#_DOWN_ARROW = u"\u21e9"
+
+# oh well, unicode support degraded from Diablo to Fremantle. let's use ASCII
+_UP_ARROW = "+"
+_DOWN_ARROW = "-"
 
 
-class ClockSetter(HBox):
+class ClockSetter(Window):
 
     def __init__(self):
     
@@ -18,28 +28,34 @@ class ClockSetter(HBox):
         self.__values = [0] * 4
         
     
-        HBox.__init__(self)
-        self.set_spacing(12)
+        Window.__init__(self, Window.TYPE_DIALOG)
+        self.set_flag(windowflags.EXCLUSIVE, True)
+        self.connect_closed(self.__on_close)
+
+        self.__hbox = HBox()
+        self.__hbox.set_spacing(12)
+        self.add(self.__hbox)
         
         for item in ["h1", "h2", ":", "m1", "m2"]:
             if (item == ":"):
-                lbl = Label(":", theme.font_mb_clocksetter,
-                            theme.color_mb_dialog_text)
+                lbl = Label(":", theme.font_sleeptimer_clocksetter,
+                                 theme.color_mb_text)
                 lbl.set_alignment(lbl.CENTERED)
-                self.add(lbl, True)
+                self.__hbox.add(lbl, True)
                 
             else:
                 vbox = VBox()
                 vbox.set_spacing(12)
-                self.add(vbox, True)
+                vbox.set_halign(VBox.HALIGN_CENTER)
+                self.__hbox.add(vbox, True)
 
                 btn = Button(_UP_ARROW)
                 btn.set_size(80, 80)
                 btn.connect_clicked(self.__on_btn_down, item)
                 vbox.add(btn, False)
 
-                lbl = Label("0", theme.font_mb_clocksetter,
-                            theme.color_mb_dialog_text)
+                lbl = Label("0", theme.font_sleeptimer_clocksetter,
+                                 theme.color_mb_text)
                 lbl.set_alignment(lbl.CENTERED)
                 vbox.add(lbl, True)
                 self.__labels.append(lbl)
@@ -52,6 +68,18 @@ class ClockSetter(HBox):
         #end for
 
 
+    def render_this(self):
+    
+        w, h = self.get_size()
+        screen = self.get_screen()
+        screen.fill_area(0, 0, w, h, theme.color_mb_background)
+        Window.render_this(self)
+
+
+    def __on_close(self):
+    
+        self.set_visible(False)
+
 
     def __on_btn_up(self, item):
     
@@ -114,3 +142,15 @@ class ClockSetter(HBox):
 
         return (h, m)
 
+
+    def run(self):
+
+        w = gtk.gdk.screen_width()
+        h = 300
+        if (platforms.MAEMO4):
+            w -= 80
+        self.set_window_size(w, h)
+        
+        Window.run(self)
+
+
