@@ -52,13 +52,19 @@ _CATEGORIES = {
     "movie":             _VIDEOS_API + "?category=Movies&orderby=published" + _SEARCH_PARAMS2,
     "news":              _VIDEOS_API + "?category=News&orderby=published" + _SEARCH_PARAMS2
 }
+_ICONS = {
+    "Search": theme.youtube_search,
+    "Today's Top Rated": theme.mb_folder_mydocs,
+    "Music": theme.mb_folder_audioclips,
+    "Movies": theme.mb_folder_videoclips
+}
 
 _REGION_BLOCKED = "region blocked"
 
 _SEARCH_CACHE_DIR = os.path.join(values.USER_DIR, "youtube/search-cache")
 _VIDEO_FOLDER = "Saved Videos"
 
-_PAGE_SIZE = 50
+_PAGE_SIZE = 25
 
 
 _STAR_CHAR = u"\u2606"
@@ -173,6 +179,8 @@ class YouTube(Device):
             f.mimetype = f.DIRECTORY
             f.path = path
             f.resource = ""
+            if (name in _ICONS):
+                f.icon = _ICONS[name].get_path()
 
         elif (path.startswith("/videos")):
             f = self.__make_video(path)
@@ -209,16 +217,16 @@ class YouTube(Device):
 
     def __ls_menu(self, cb, *args):
     
-        for name, category, icon in [
-            ("Search", "video", theme.youtube_search),
-            ("Recently Featured", "recently_featured", None),
-            ("Today's Top Rated", "top_rated", None),
-            ("Most Viewed", "most_viewed", None),
-            ("Most Popular", "most_popular", None),
-            ("Music", "music", None),
-            ("Movies", "movie", None),
-            ("News", "news", None),
-            ("For Mobile Phones", "watch_on_mobile", None)
+        for name, category in [
+            ("Search", "video"),
+            ("Recently Featured", "recently_featured"),
+            ("Today's Top Rated", "top_rated"),
+            ("Most Viewed", "most_viewed"),
+            ("Most Popular", "most_popular"),
+            ("Music", "music"),
+            ("Movies", "movie"),
+            ("News", "news"),
+            ("For Mobile Phones", "watch_on_mobile")
         ]:
             item = File(self)
             query = ""
@@ -227,8 +235,9 @@ class YouTube(Device):
             item.resource = item.path
             item.name = name
             item.mimetype = File.DIRECTORY
-            if (icon):
-                item.icon = icon.get_path()
+            item.folder_flags = File.ITEMS_UNSORTED
+            if (name in _ICONS):
+                item.icon = _ICONS[name].get_path()
             
             cb(item, *args)
         #end for
@@ -238,7 +247,13 @@ class YouTube(Device):
 
     def __on_receive_xml(self, data, amount, total, xml, category, query, is_toc, cb, *args):
     
-        if (not data):
+        if (data == None):
+            # error
+            logging.error("error downloading XML data")
+            self.__current_folder.message = "content not available"
+            cb(None, *args)
+            
+        elif (not data):
             # finished loading
             #self.__cache_search_result(url, xml[0])
             if (is_toc):
@@ -258,7 +273,7 @@ class YouTube(Device):
                 total_results = int(node.get_pcdata())
                 
                 # set a sane limit (YouTube cannot handle more anyway)
-                total_results = min(total_results, 40 * _PAGE_SIZE)
+                total_results = min(total_results, 20 * _PAGE_SIZE)
                 
                 page = 1
                 for n in range(1, total_results, _PAGE_SIZE):
@@ -267,6 +282,7 @@ class YouTube(Device):
                     f.path = File.pack_path("/search", f.name, category, query, n)
                     f.mimetype = f.DIRECTORY
                     f.info = "Results %d - %d" % (n, min(total_results, n + _PAGE_SIZE - 1))
+                    f.folder_flags = File.ITEMS_UNSORTED
                     cb(f, *args)
                     page += 1
                 #end for
@@ -376,12 +392,11 @@ class YouTube(Device):
         mins = duration
 
         info = "by %s\n" \
-               "Duration: %d:%02d\tViews: %d\t" \
-               "Rating: %s" \
+               "%d:%02d\t%s\t%s views" \
                % (authors,
                   mins, secs,
-                  view_count,
-                  rating)
+                  rating,
+                  view_count)
 
         path = File.pack_path("/videos", title, info, video_id, thumbnail_url)
         
@@ -555,6 +570,9 @@ class YouTube(Device):
             logging.error("could not retrieve video\n%s", logging.stacktrace())
             return ""
 
+        if (not 18 in fmts): fmts.append(18)
+        fmts.sort()
+
         # filter out incompatible formats
         if (platforms.MAEMO5):
             fmts = [ fmt for fmt in fmts if fmt in _N900_FORMAT_WHITELIST ]
@@ -564,12 +582,13 @@ class YouTube(Device):
         # retrieve high-quality version, if desired
         if (len(fmts) > 1):
             qtype = self.__ask_for_quality(fmts)
+        elif (len(fmts) == 1):
+            qtype = fmts[0]
         else:
             qtype = 0
 
         print "Requested Video Quality:", qtype
 
-        #qtype = config.get_quality_type()
         if (qtype in fmts):
             flv = flv + "&fmt=%d" % qtype
             ext = "." + formats.get_container(qtype)
@@ -611,6 +630,8 @@ class YouTube(Device):
                 return ""
             flv_path = os.path.join(cache_folder, ".tube.flv")
 
+            # the mplayer backend on Maemo5 doesn't work well with directly
+            # taking an URL from YouTube for some reason
             self.__flv_downloader = FileDownloader(url, flv_path, on_dload)
         
             # we don't give the downloaded file directly to the player because
@@ -664,19 +685,3 @@ class YouTube(Device):
 
         return actions
 
-
-    def __make_filename(self, name, ext):
-        """
-        Creates a (hopefully) valid filename from the given name.
-        """
-        
-        replace_map = [("/", "-"),
-                       ("?", ""),
-                       ("\\", "-"),
-                       (":", "-")]
-                       
-        for a, b in replace_map:
-            name = name.replace(a, b)
-
-        return name + ext
-
