@@ -6,6 +6,7 @@ import os
 MAEMO4 = ""
 MAEMO5 = ""
 MER = ""
+MEEGO_NETBOOK = ""
 COMPUTER = ""
 HTPC = ""
 
@@ -32,6 +33,12 @@ def _check_mer():
     return (v == 0)
     
     
+def _check_meego_netbook():
+
+    v = os.system("cat /etc/meego-release | grep netbook >/dev/null")
+    return (v == 0)
+    
+    
 def _check_htpc():
 
     v = os.system("lsmod | grep appleir >/dev/null")
@@ -58,6 +65,11 @@ elif _check_mer():
     MER = "mer"
     logging.info("using MER target")
 
+elif _check_meego_netbook():
+    from meego_netbook import *
+    MEEGO_NETBOOK = "meego_netbook"
+    logging.info("using MEEGO_NETBOOK target")
+
 elif _check_htpc():
     from htpc import *
     HTPC = "htpc"
