@@ -62,6 +62,9 @@ class Window(Widget):
         self.__has_size_set = False
         self.__is_button_pressed = False
         self.__screen = None
+
+        # timeout handler for handling the window configure events
+        self.__configure_event_handler = None
         
         Widget.__init__(self)
 
@@ -292,13 +295,26 @@ class Window(Widget):
 
     def __update_window_background(self):
         
-        self.__window.modify_bg(gtk.STATE_NORMAL,
-                          gtk.gdk.color_parse(str(theme.color_mb_background)))
-
+        #self.__window.modify_bg(gtk.STATE_NORMAL,
+        #                  gtk.gdk.color_parse(str(theme.color_mb_background)))
+        pass
 
 
     def __on_configure(self, src, ev):
 
+        if (self.__configure_event_handler):
+            gobject.source_remove(self.__configure_event_handler)
+        self.__configure_event_handler = gobject.timeout_add(0, 
+                                                self.__handle_configure_event)
+
+
+    def __handle_configure_event(self):
+        """
+        Handles the last window configure event in a row. Maemo5 sometimes
+        shoots several in a row and we should only react on the last one.
+        """
+
+        self.__configure_event_handler = None
         w, h = self.__window.get_size()
         if ((w, h) != self.__size):
             self.__screen = Pixmap(self.__window.window)
@@ -308,10 +324,10 @@ class Window(Widget):
             self.set_size(w, h)
             self.render()
         #end if
-            
+
 
     def __on_expose(self, src, ev):
-    
+                
         if (self.__screen):
             x, y, w, h = ev.area
             self.__screen.restore(x, y, w, h)
